Hello community,

here is the log from the commit of package python-gabbi for openSUSE:Factory 
checked in at 2020-06-26 21:48:51
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/python-gabbi (Old)
 and      /work/SRC/openSUSE:Factory/.python-gabbi.new.3060 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "python-gabbi"

Fri Jun 26 21:48:51 2020 rev:9 rq:817197 version:2.0.3

Changes:
--------
--- /work/SRC/openSUSE:Factory/python-gabbi/python-gabbi.changes        
2019-08-13 13:24:34.273366173 +0200
+++ /work/SRC/openSUSE:Factory/.python-gabbi.new.3060/python-gabbi.changes      
2020-06-26 21:49:15.098562513 +0200
@@ -1,0 +2,9 @@
+Fri Jun 26 07:18:19 UTC 2020 - Dirk Mueller <[email protected]>
+
+- update to 2.0.3:
+  * remove universal wheel creation
+  * Declare package as Python3-only (#281)
+  * Correct defaults being copied between suites
+  * Drop support for py2 and remove testtools (#279)
+
+-------------------------------------------------------------------

Old:
----
  gabbi-1.49.0.tar.gz

New:
----
  gabbi-2.0.3.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ python-gabbi.spec ++++++
--- /var/tmp/diff_new_pack.ZA7w6s/_old  2020-06-26 21:49:15.922565165 +0200
+++ /var/tmp/diff_new_pack.ZA7w6s/_new  2020-06-26 21:49:15.922565165 +0200
@@ -1,7 +1,7 @@
 #
 # spec file for package python-gabbi
 #
-# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2020 SUSE LLC
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -18,7 +18,7 @@
 
 %{?!python_module:%define python_module() python-%{**} python3-%{**}}
 Name:           python-gabbi
-Version:        1.49.0
+Version:        2.0.3
 Release:        0
 Summary:        Declarative HTTP testing library
 License:        Apache-2.0
@@ -42,7 +42,6 @@
 Requires:       python-jsonpath-rw-ext >= 1.0.0
 Requires:       python-pytest
 Requires:       python-six
-Requires:       python-testtools
 Requires:       python-urllib3 >= 1.11.0
 Requires:       python-wsgi_intercept >= 1.8.1
 Requires(post): update-alternatives

++++++ gabbi-1.49.0.tar.gz -> gabbi-2.0.3.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/.travis.yml new/gabbi-2.0.3/.travis.yml
--- old/gabbi-1.49.0/.travis.yml        2018-12-07 11:33:14.000000000 +0100
+++ new/gabbi-2.0.3/.travis.yml 2020-04-30 18:41:52.000000000 +0200
@@ -1,46 +1,25 @@
 sudo: false
 dist: xenial
 language: python
-services:
-  # For Gnocchi
-  - docker
 install:
-      - |
-        if [ "$TOXENV" == "gnocchi" ]; then
-            docker pull gnocchixyz/ci-tools:latest
-        else
-            pip install tox
-        fi
+      - pip install tox
 script:
-      - |
-        case "$TOXENV" in
-            gnocchi)
-              docker run -v ~/.cache/pip:/home/tester/.cache/pip -v 
$(pwd):/home/tester/src gnocchixyz/ci-tools:latest tox -e ${TOXENV}
-              ;;
-            *)
-              tox
-              ;;
-        esac
+      - tox
 matrix:
     include:
-        - env: TOXENV=py27
         - env: TOXENV=pep8
-        - env: TOXENV=py27-pytest
-        - env: TOXENV=gnocchi
         - python: 3.7
           env: TOXENV=placement
-        - python: pypy
-          env: TOXENV=pypy
-          dist: trusty
         - python: pypy3
           env: TOXENV=pypy3
-          dist: trusty
         - python: 3.5
           env: TOXENV=py35
         - python: 3.6
           env: TOXENV=py36
         - python: 3.7
           env: TOXENV=py37
+        - python: 3.8
+          env: TOXENV=py38
         - python: 3.5
           env: TOXENV=py35-pytest
         - python: 3.6
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/AUTHORS new/gabbi-2.0.3/AUTHORS
--- old/gabbi-1.49.0/AUTHORS    2019-08-07 16:48:13.000000000 +0200
+++ new/gabbi-2.0.3/AUTHORS     2020-06-05 13:34:06.000000000 +0200
@@ -17,6 +17,7 @@
 Mehdi Abaakouk <[email protected]>
 Mehdi Abaakouk <[email protected]>
 Michael McCune <[email protected]>
+Pavlo Shchelokovskyy <[email protected]>
 Ryan James Spencer <[email protected]>
 Ryan Spencer <[email protected]>
 Samuel Fekete <[email protected]>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/ChangeLog new/gabbi-2.0.3/ChangeLog
--- old/gabbi-1.49.0/ChangeLog  2019-08-07 16:48:13.000000000 +0200
+++ new/gabbi-2.0.3/ChangeLog   2020-06-05 13:34:06.000000000 +0200
@@ -1,6 +1,29 @@
 CHANGES
 =======
 
+2.0.3
+-----
+
+* release 2.0.3
+* remove universal wheel creation
+
+2.0.2
+-----
+
+* release 2.0.2
+* Declare package as Python3-only (#281)
+
+2.0.1
+-----
+
+* Release 2.0.1
+* Correct defaults being copied between suites
+
+2.0.0
+-----
+
+* Drop support for py2 and remove testtools (#279)
+
 1.49.0
 ------
 
@@ -22,6 +45,10 @@
 * Release 1.47.0
 * Clean up test warning and tox misconfigurations
 * Pin pytest to <5.0.0
+
+1.46.0
+------
+
 * release 1.46.0
 * Work around issues in urllib3
 * Enable a -q arg to gabbi-run
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/PKG-INFO new/gabbi-2.0.3/PKG-INFO
--- old/gabbi-1.49.0/PKG-INFO   2019-08-07 16:48:13.000000000 +0200
+++ new/gabbi-2.0.3/PKG-INFO    2020-06-05 13:34:06.000000000 +0200
@@ -1,6 +1,6 @@
-Metadata-Version: 1.1
+Metadata-Version: 1.2
 Name: gabbi
-Version: 1.49.0
+Version: 2.0.3
 Summary: Declarative HTTP testing library
 Home-page: https://github.com/cdent/gabbi
 Author: Chris Dent
@@ -28,7 +28,7 @@
         See the docs_ for more details on the many features and formats for
         setting request headers and bodies and evaluating responses.
         
-        Gabbi is tested with Python 2.7, 3.5, 3.6, 3.7 and pypy.
+        Gabbi is tested with Python 3.5, 3.6, 3.7 and pypy3.
         
         Tests can be run using `unittest`_ style test runners, `pytest`_
         or from the command line with a `gabbi-run`_ script.
@@ -92,7 +92,7 @@
         are in the directories ``gabbi/tests/gabbits_*`` and loaded by the file
         ``gabbi/test_*.py``), you call ``tox``::
         
-            tox -epep8,py27,py34
+            tox -epep8,py37
         
         If you have the dependencies installed (or a warmed up
         virtualenv) you can run the tests by hand and exit on the first
@@ -103,7 +103,7 @@
         Testing can be limited to individual modules by specifying them
         after the tox invocation::
         
-            tox -epep8,py27,py34 -- test_driver test_handlers
+            tox -epep8,py37 -- test_driver test_handlers
         
         If you wish to avoid running tests that connect to internet hosts,
         set ``GABBI_SKIP_NETWORK`` to ``True``.
@@ -119,11 +119,11 @@
 Classifier: License :: OSI Approved :: Apache Software License
 Classifier: Operating System :: POSIX
 Classifier: Programming Language :: Python
-Classifier: Programming Language :: Python :: 2
-Classifier: Programming Language :: Python :: 2.7
 Classifier: Programming Language :: Python :: 3
 Classifier: Programming Language :: Python :: 3.5
 Classifier: Programming Language :: Python :: 3.6
 Classifier: Programming Language :: Python :: 3.7
+Classifier: Programming Language :: Python :: 3 :: Only
 Classifier: Topic :: Internet :: WWW/HTTP :: WSGI
 Classifier: Topic :: Software Development :: Testing
+Requires-Python: >=3.5
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/README.rst new/gabbi-2.0.3/README.rst
--- old/gabbi-1.49.0/README.rst 2018-12-06 19:50:45.000000000 +0100
+++ new/gabbi-2.0.3/README.rst  2020-04-30 18:41:52.000000000 +0200
@@ -20,7 +20,7 @@
 See the docs_ for more details on the many features and formats for
 setting request headers and bodies and evaluating responses.
 
-Gabbi is tested with Python 2.7, 3.5, 3.6, 3.7 and pypy.
+Gabbi is tested with Python 3.5, 3.6, 3.7 and pypy3.
 
 Tests can be run using `unittest`_ style test runners, `pytest`_
 or from the command line with a `gabbi-run`_ script.
@@ -84,7 +84,7 @@
 are in the directories ``gabbi/tests/gabbits_*`` and loaded by the file
 ``gabbi/test_*.py``), you call ``tox``::
 
-    tox -epep8,py27,py34
+    tox -epep8,py37
 
 If you have the dependencies installed (or a warmed up
 virtualenv) you can run the tests by hand and exit on the first
@@ -95,7 +95,7 @@
 Testing can be limited to individual modules by specifying them
 after the tox invocation::
 
-    tox -epep8,py27,py34 -- test_driver test_handlers
+    tox -epep8,py37 -- test_driver test_handlers
 
 If you wish to avoid running tests that connect to internet hosts,
 set ``GABBI_SKIP_NETWORK`` to ``True``.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/docs/source/index.rst 
new/gabbi-2.0.3/docs/source/index.rst
--- old/gabbi-1.49.0/docs/source/index.rst      2018-10-04 16:38:30.000000000 
+0200
+++ new/gabbi-2.0.3/docs/source/index.rst       2020-04-30 18:41:52.000000000 
+0200
@@ -111,8 +111,6 @@
 
     pip install gabbi
 
-(both Python 2 and Python 3 are supported)
-
 You might want to create a virtual environment; an isolated context for
 Python packages, keeping gabbi cleany separated from the rest of your
 system.
@@ -123,14 +121,6 @@
     . venv/bin/activate
 
     pip install gabbi
-
-Alternatively, with Python 2 we can use `virtualenv`_::
-
-    pip install virtualenv
-    virtualenv venv
-    . venv/bin/activate
-
-    pip install gabbi
 
 This way we can later use ``deactivate`` and safely remove the ``venv``
 directory, thus erasing any trace of gabbi from the system.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/docs/source/release.rst 
new/gabbi-2.0.3/docs/source/release.rst
--- old/gabbi-1.49.0/docs/source/release.rst    2019-08-07 16:22:06.000000000 
+0200
+++ new/gabbi-2.0.3/docs/source/release.rst     2020-06-05 13:23:52.000000000 
+0200
@@ -5,6 +5,27 @@
 highlighting major features and changes. For more detail see
 the `commit logs`_ on GitHub.
 
+2.0.3
+-----
+
+* Properly declare that gabbi 2.x is Python 3 only.
+
+2.0.1
+-----
+
+* Correct management of response handler default fields.
+
+2.0.0
+-----
+
+* Drop support for Python 2. If you need Python 2 support, use an older 
version.
+* Stop using ``testtools`` and ``fixtures``. These two modules present several
+  difficulties and their maintenance situation suggests those difficulties
+  will not be resolved. Since Python 2 support is being removed, the need for
+  the modules can be removed as well without losing functionality. "Inner
+  fixtures" that use the ``fixtures.Fixture`` interface should continue to
+  work.
+
 1.49.0
 ------
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi/__init__.py 
new/gabbi-2.0.3/gabbi/__init__.py
--- old/gabbi-1.49.0/gabbi/__init__.py  2019-08-07 16:23:32.000000000 +0200
+++ new/gabbi-2.0.3/gabbi/__init__.py   2020-06-05 13:23:44.000000000 +0200
@@ -12,4 +12,4 @@
 # under the License.
 """See gabbi.driver and gabbbi.case."""
 
-__version__ = '1.49.0'
+__version__ = '2.0.3'
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi/driver.py 
new/gabbi-2.0.3/gabbi/driver.py
--- old/gabbi-1.49.0/gabbi/driver.py    2019-08-07 14:40:23.000000000 +0200
+++ new/gabbi-2.0.3/gabbi/driver.py     2020-04-30 18:41:52.000000000 +0200
@@ -65,6 +65,8 @@
     :param require_ssl: If ``True``, make all tests default to using SSL.
     :param inner_fixtures: A list of ``Fixtures`` to use with each
                            individual test request.
+    :type inner_fixtures: List of classes with setUp and cleanUp methods to
+                          be used as fixtures.
     :param verbose: If ``True`` or ``'all'``, make tests verbose by default
                     ``'headers'`` and ``'body'`` are also accepted.
     :param use_prior_test: If ``True``, uses prior test to create ordered
@@ -74,7 +76,6 @@
     :param cert_validate: If ``False`` ssl server certificate will be ignored,
                         further it will not be validated if provided
                         (set cert_reqs=CERT_NONE to the Http object)
-    :type inner_fixtures: List of fixtures.Fixture classes.
     :rtype: TestSuite containing multiple TestSuites (one for each YAML file).
     """
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi/suite.py 
new/gabbi-2.0.3/gabbi/suite.py
--- old/gabbi-1.49.0/gabbi/suite.py     2018-06-28 15:18:51.000000000 +0200
+++ new/gabbi-2.0.3/gabbi/suite.py      2020-04-30 18:41:52.000000000 +0200
@@ -71,7 +71,7 @@
         # the entire suite is skipped, and the result stream told
         # we're done. If there are no tests (an empty suite) the
         # exception is re-raised.
-        except Exception as exc:
+        except Exception:
             if self._tests:
                 result.addError(self._tests[0], sys.exc_info())
                 for test in self._tests:
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi/suitemaker.py 
new/gabbi-2.0.3/gabbi/suitemaker.py
--- old/gabbi-1.49.0/gabbi/suitemaker.py        2019-08-07 14:40:23.000000000 
+0200
+++ new/gabbi-2.0.3/gabbi/suitemaker.py 2020-05-01 16:43:19.000000000 +0200
@@ -19,6 +19,7 @@
 
 import copy
 import functools
+import unittest
 
 from gabbi import case
 from gabbi.exception import GabbiFormatError
@@ -90,7 +91,7 @@
         test_method_name = 'test_request'
         test_method = getattr(case.HTTPTestCase, test_method_name)
 
-        @case.testcase.skipIf(self.host == '', 'No host configured')
+        @unittest.skipIf(self.host == '', 'No host configured')
         @functools.wraps(test_method)
         def do_test(*args, **kwargs):
             return test_method(*args, **kwargs)
@@ -220,7 +221,7 @@
     default_test_dict = copy.deepcopy(case.HTTPTestCase.base_test)
     seen_keys = set()
     for handler in handlers:
-        default_test_dict.update(handler.test_base)
+        default_test_dict.update(copy.deepcopy(handler.test_base))
         if handler.response_handler:
             if handler.test_key_suffix not in seen_keys:
                 response_handlers.append(handler.response_handler)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi/tests/test_inner_fixture.py 
new/gabbi-2.0.3/gabbi/tests/test_inner_fixture.py
--- old/gabbi-1.49.0/gabbi/tests/test_inner_fixture.py  2018-06-28 
15:18:51.000000000 +0200
+++ new/gabbi-2.0.3/gabbi/tests/test_inner_fixture.py   2020-04-30 
18:41:52.000000000 +0200
@@ -18,8 +18,6 @@
 import os
 import sys
 
-import fixtures
-
 from gabbi import driver
 # TODO(cdent): test_pytest allows pytest to see the tests this module
 # produces. Without it, the generator will not run. It is a todo because
@@ -45,16 +43,14 @@
         assert COUNT_OUTER == 1
 
 
-class InnerFixture(fixtures.Fixture):
+class InnerFixture(object):
     """Test that setUp is called 3 times."""
 
     def setUp(self):
-        super(InnerFixture, self).setUp()
         global COUNT_INNER
         COUNT_INNER += 1
 
-    def cleanUp(self, raise_first=True):
-        super(InnerFixture, self).cleanUp()
+    def cleanUp(self):
         assert 1 <= COUNT_INNER <= 3
 
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi.egg-info/PKG-INFO 
new/gabbi-2.0.3/gabbi.egg-info/PKG-INFO
--- old/gabbi-1.49.0/gabbi.egg-info/PKG-INFO    2019-08-07 16:48:13.000000000 
+0200
+++ new/gabbi-2.0.3/gabbi.egg-info/PKG-INFO     2020-06-05 13:34:06.000000000 
+0200
@@ -1,6 +1,6 @@
-Metadata-Version: 1.1
+Metadata-Version: 1.2
 Name: gabbi
-Version: 1.49.0
+Version: 2.0.3
 Summary: Declarative HTTP testing library
 Home-page: https://github.com/cdent/gabbi
 Author: Chris Dent
@@ -28,7 +28,7 @@
         See the docs_ for more details on the many features and formats for
         setting request headers and bodies and evaluating responses.
         
-        Gabbi is tested with Python 2.7, 3.5, 3.6, 3.7 and pypy.
+        Gabbi is tested with Python 3.5, 3.6, 3.7 and pypy3.
         
         Tests can be run using `unittest`_ style test runners, `pytest`_
         or from the command line with a `gabbi-run`_ script.
@@ -92,7 +92,7 @@
         are in the directories ``gabbi/tests/gabbits_*`` and loaded by the file
         ``gabbi/test_*.py``), you call ``tox``::
         
-            tox -epep8,py27,py34
+            tox -epep8,py37
         
         If you have the dependencies installed (or a warmed up
         virtualenv) you can run the tests by hand and exit on the first
@@ -103,7 +103,7 @@
         Testing can be limited to individual modules by specifying them
         after the tox invocation::
         
-            tox -epep8,py27,py34 -- test_driver test_handlers
+            tox -epep8,py37 -- test_driver test_handlers
         
         If you wish to avoid running tests that connect to internet hosts,
         set ``GABBI_SKIP_NETWORK`` to ``True``.
@@ -119,11 +119,11 @@
 Classifier: License :: OSI Approved :: Apache Software License
 Classifier: Operating System :: POSIX
 Classifier: Programming Language :: Python
-Classifier: Programming Language :: Python :: 2
-Classifier: Programming Language :: Python :: 2.7
 Classifier: Programming Language :: Python :: 3
 Classifier: Programming Language :: Python :: 3.5
 Classifier: Programming Language :: Python :: 3.6
 Classifier: Programming Language :: Python :: 3.7
+Classifier: Programming Language :: Python :: 3 :: Only
 Classifier: Topic :: Internet :: WWW/HTTP :: WSGI
 Classifier: Topic :: Software Development :: Testing
+Requires-Python: >=3.5
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi.egg-info/pbr.json 
new/gabbi-2.0.3/gabbi.egg-info/pbr.json
--- old/gabbi-1.49.0/gabbi.egg-info/pbr.json    2019-08-07 16:48:13.000000000 
+0200
+++ new/gabbi-2.0.3/gabbi.egg-info/pbr.json     2020-06-05 13:34:06.000000000 
+0200
@@ -1 +1 @@
-{"git_version": "8e02d4d", "is_release": true}
\ No newline at end of file
+{"git_version": "8aa4e70", "is_release": true}
\ No newline at end of file
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi.egg-info/requires.txt 
new/gabbi-2.0.3/gabbi.egg-info/requires.txt
--- old/gabbi-1.49.0/gabbi.egg-info/requires.txt        2019-08-07 
16:48:13.000000000 +0200
+++ new/gabbi-2.0.3/gabbi.egg-info/requires.txt 2020-06-05 13:34:06.000000000 
+0200
@@ -7,4 +7,3 @@
 jsonpath-rw-ext>=1.0.0
 wsgi-intercept>=1.8.1
 colorama
-testtools
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/requirements.txt 
new/gabbi-2.0.3/requirements.txt
--- old/gabbi-1.49.0/requirements.txt   2019-07-01 16:04:18.000000000 +0200
+++ new/gabbi-2.0.3/requirements.txt    2020-04-30 18:41:52.000000000 +0200
@@ -7,4 +7,3 @@
 jsonpath-rw-ext>=1.0.0
 wsgi-intercept>=1.8.1
 colorama
-testtools
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/setup.cfg new/gabbi-2.0.3/setup.cfg
--- old/gabbi-1.49.0/setup.cfg  2019-08-07 16:48:13.000000000 +0200
+++ new/gabbi-2.0.3/setup.cfg   2020-06-05 13:34:06.000000000 +0200
@@ -6,6 +6,7 @@
 description-file = README.rst
 license = Apache-2
 home-page = https://github.com/cdent/gabbi
+python-requires = >=3.5
 classifier = 
        Intended Audience :: Developers
        Intended Audience :: Information Technology
@@ -13,12 +14,11 @@
        License :: OSI Approved :: Apache Software License
        Operating System :: POSIX
        Programming Language :: Python
-       Programming Language :: Python :: 2
-       Programming Language :: Python :: 2.7
        Programming Language :: Python :: 3
        Programming Language :: Python :: 3.5
        Programming Language :: Python :: 3.6
        Programming Language :: Python :: 3.7
+       Programming Language :: Python :: 3 :: Only
        Topic :: Internet :: WWW/HTTP :: WSGI
        Topic :: Software Development :: Testing
 
@@ -35,9 +35,6 @@
 console_scripts = 
        gabbi-run = gabbi.runner:run
 
-[bdist_wheel]
-universal = 1
-
 [egg_info]
 tag_build = 
 tag_date = 0
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/tox.ini new/gabbi-2.0.3/tox.ini
--- old/gabbi-1.49.0/tox.ini    2019-08-07 14:59:57.000000000 +0200
+++ new/gabbi-2.0.3/tox.ini     2020-04-30 18:41:52.000000000 +0200
@@ -1,7 +1,7 @@
 [tox]
 minversion = 3.1.1
 skipsdist = True
-envlist = 
py27,py35,py36,py37,pypy,pep8,limit,failskip,docs,py37-prefix,py37-limit,py37-failskip,py27-pytest,py35-pytest,py36-pytest,py37-pytest
+envlist = 
py35,py36,py37,py38,pypy3,pep8,limit,failskip,docs,py37-prefix,py37-limit,py37-failskip,py35-pytest,py36-pytest,py37-pytest
 
 [testenv]
 deps = -r{toxinidir}/requirements.txt
@@ -19,9 +19,6 @@
        -r{toxinidir}/test-requirements.txt
 commands = {posargs}
 
-[testenv:py27-pytest]
-commands = py.test gabbi
-
 [testenv:py35-pytest]
 commands = py.test gabbi
 
@@ -40,12 +37,6 @@
 commands =
     flake8
 
-[testenv:limit]
-commands = {toxinidir}/test-limit.sh
-
-[testenv:failskip]
-commands = {toxinidir}/test-failskip.sh
-
 [testenv:py37-limit]
 commands = {toxinidir}/test-limit.sh
 
@@ -53,6 +44,7 @@
 commands = {toxinidir}/test-failskip.sh
 
 [testenv:cover]
+basepython = python3
 setenv =
     {[testenv]setenv}
     PYTHON=coverage run --source gabbi --parallel-mode
@@ -66,23 +58,15 @@
     coverage report
 
 [testenv:pytest-cov]
+basepython = python3
 commands = py.test --cov=gabbi gabbi/tests --cov-config .coveragerc 
--cov-report html
 
-[testenv:gnocchi]
-basepython = python2.7
-deps = -egit+https://github.com/gnocchixyz/gnocchi#egg=gnocchi
-       tox
-changedir = {envdir}/src/gnocchi
-commands = tox -e py27-postgresql-file --notest  # ensure a virtualenv is built
-           {envdir}/src/gnocchi/.tox/py27-postgresql-file/bin/pip install -U 
{toxinidir}  # install gabbi
-           tox -e py27-postgresql-file gabbi
-
 [testenv:placement]
 basepython = python3.7
 deps = tox
 commands = -mkdir {envdir}/src
            -rm -r {envdir}/src/*
-           bash -c "curl 
https://tarballs.openstack.org/placement/placement-master.tar.gz | tar -C 
{envdir}/src -zx --strip-components 1 -f - "
+           bash -c "curl -L 
https://tarballs.opendev.org/openstack/placement/placement-master.tar.gz | tar 
-C {envdir}/src -zx --strip-components 1 -f - "
            tox -c {envdir}/src -e functional-py37 --notest  # ensure a 
virtualenv is built
            # nova shares tox envs so it's just luck that we know the tox dir 
is different from name
            {envdir}/src/.tox/py37/bin/pip install -U {toxinidir}  # install 
gabbi


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/gabbi-1.49.0/gabbi/case.py 
new/gabbi-2.0.3/gabbi/case.py
--- old/gabbi-1.49.0/gabbi/case.py      2019-08-07 14:40:23.000000000 +0200
+++ new/gabbi-2.0.3/gabbi/case.py       2020-04-30 18:41:52.000000000 +0200
@@ -10,7 +10,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
 """A single HTTP request represented as a subclass of ``testtools.TestCase``
 
 The test case encapsulates the request headers and body and expected
 response headers and body. When the test is run an HTTP request is
@@ -24,13 +24,12 @@
 import re
 import sys
 import time
+import unittest
 from unittest import result as unitresult
 
 import six
 from six.moves import http_cookies
 from six.moves.urllib import parse as urlparse
-import testtools
-from testtools import testcase
 import wsgi_intercept
 
 from gabbi import __version__
@@ -82,15 +81,9 @@
             try:
                 func(self)
             except Exception:
-                if hasattr(testcase, '_ExpectedFailure'):
-                    raise testcase._ExpectedFailure(sys.exc_info())
-                else:
-                    self._addExpectedFailure(self.result, sys.exc_info())
+                self._addExpectedFailure(self.result, sys.exc_info())
             else:
-                if hasattr(self, '_addUnexpectedSuccess'):
-                    self._addUnexpectedSuccess(self.result)
-                else:
-                    raise testcase._UnexpectedSuccess
+                self._addUnexpectedSuccess(self.result)
         else:
             func(self)
     return wrapper
@@ -101,7 +94,7 @@
     return isinstance(data, list) or isinstance(data, dict)
 
 
-class HTTPTestCase(testtools.TestCase):
+class HTTPTestCase(unittest.TestCase):
     """Encapsulate a single HTTP request as a TestCase.
 
     If the test is a member of a sequence of requests, ensure that prior
@@ -114,15 +107,23 @@
     base_test = copy.copy(BASE_TEST)
 
     def setUp(self):
+        self._fixture_cleanups = []
         if not self.has_run:
             super(HTTPTestCase, self).setUp()
             for fixture in self.inner_fixtures:
-                self.useFixture(fixture())
+                f = fixture()
+                f.setUp()
+                # add fixture to front of list so we unwind them FILO in
+                # tearDown
+                self._fixture_cleanups.insert(0, f)
 
     def tearDown(self):
         if not self.has_run:
             super(HTTPTestCase, self).tearDown()
         self.has_run = True
+        # Clean up an inner fixtures.
+        for fixture in self._fixture_cleanups:
+            fixture.cleanUp()
 
     def run(self, result=None):
         """Store the current result handler on this test."""
@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
-"""A single HTTP request represented as a subclass of ``testtools.TestCase``
+"""A single HTTP request represented as a subclass of ``unittest.TestCase``
 
 The test case encapsulates the request headers and body and expected